@@ -64,7 +64,6 @@ impl fmt::Display for OutputFormat {
 ///  * `$XDG_CONFIG_HOME/git/config` --- the __XDG__ config
 ///  * `$HOME/.gitconfig` --- the __global__ config
 ///  * `$GIT_DIR/.git/config` --- the repo-specific or __local__ config
-///  * The environment variables `GITLAB_HOST`, `GITLAB_TOKEN` and `GITLAB_TLS`
 ///
 /// Override priority increases from top to bottom.
 #[derive(Debug)]
@@ -144,11 +143,11 @@ where
     V: Iterator<Item = (String, String)> // use a trait bound to aid testing
 
 {
-    let gitlab_vars = vars.filter(|(k, _)| k.starts_with("GITLAB_"));
+    let gitlab_vars = vars.filter(|(k, _)| k.starts_with("GITLABCLI_"));
     for (key, value) in gitlab_vars {
-        if key == "GITLAB_TOKEN" { config.token = Some(value); continue };
-        if key == "GITLAB_HOST" { config.host = Some(value); continue };
-        if key == "GITLAB_TLS" {
+        if key == "GITLABCLI_TOKEN" { config.token = Some(value); continue };
+        if key == "GITLABCLI_HOST" { config.host = Some(value); continue };
+        if key == "GITLABCLI_TLS" {
             config.tls = Some(
                 value.to_uppercase() == "TRUE" ||
                 value.to_uppercase() == "YES" ||
@@ -157,8 +156,8 @@ where
                 );
             continue
         };
-        if key == "GITLAB_FORMAT" { config.format = value.parse::<OutputFormat>().ok(); continue };
-        if key == "GITLAB_PROJECTID" { config.projectid = value.parse::<u64>().ok(); continue };
+        if key == "GITLABCLI_FORMAT" { config.format = value.parse::<OutputFormat>().ok(); continue };
+        if key == "GITLABCLI_PROJECTID" { config.projectid = value.parse::<u64>().ok(); continue };
     }
 }
 
@@ -174,7 +173,6 @@ fn get_level_config(multi_level: &GitConfig, level: ConfigLevel) -> GitConfig {
             GitConfig::new().unwrap()
         }
     }
-
 }
 
 /// Return which type of user config is being used. Is it Global ($HOME/.gitconfig)
@@ -189,30 +187,47 @@ fn get_user_config_type() -> Option<UserGitConfigLevel> {
     }
 }
 
-/// Write config data to a git config
+/// Write config data to a git config,
 fn write_config(save_config: &mut GitConfig, config: &Config) -> Result<()> {
 
-    if config.host.is_some() {
+    if config.host.is_some()
+        && ( env::var("GITLABCLI_HOST").is_err()
+            || &env::var("GITLABCLI_HOST").unwrap() != config.host.as_ref().unwrap()
+           )
+    {
         save_config.set_str("gitlab.host", config.host.as_ref().unwrap())
             .context("Failed to save gitlab.host to git config.")?;
     }
 
-    if config.token.is_some() {
+    if config.token.is_some()
+        && ( env::var("GITLABCLI_TOKEN").is_err()
+            || &env::var("GITLABCLI_TOKEN").unwrap() != config.token.as_ref().unwrap()
+           )
+    {
         save_config.set_str("gitlab.token", config.token.as_ref().unwrap())
             .context("Failed to save gitlab.token to git config.")?;
     }
 
+    // no environment checking for booleans, probably should be done at some point
     if config.tls.is_some() {
         save_config.set_bool("gitlab.tls", config.tls.unwrap())
             .context("Failed to save gitlab.tls to git config.")?;
     }
 
-    if config.format.is_some() {
-        save_config.set_str("gitlab.format", config.format.as_ref().unwrap().to_string().as_str())
+    if config.format.is_some()
+        && ( env::var("GITLABCLI_FORMAT").is_err()
+            || env::var("GITLABCLI_FORMAT").unwrap().to_lowercase() != config.format.as_ref().unwrap().to_string().to_lowercase()
+           )
+    {
+        save_config.set_str("gitlab.format", config.format.as_ref().unwrap().to_string().to_lowercase().as_str())
             .context("Failed to save gitlab.format to git config.")?;
     }
 
-    if config.projectid.is_some() {
+    if config.projectid.is_some()
+        && ( env::var("GITLABCLI_PROJECTID").is_err()
+            || env::var("GITLABCLI_PROJECTID").unwrap() != config.projectid.as_ref().unwrap().to_string()
+           )
+    {
         save_config.set_i64("gitlab.projectid", i64::try_from(config.projectid.unwrap()).unwrap())
             .context("Failed to save gitlab.projectid to git config.")?;
     }
@@ -639,10 +654,10 @@ mod config_unit_tests {
         use std::collections::HashMap;
         let mut env = HashMap::new();
 
-        env.insert("GITLAB_TOKEN".to_string(), "env_token".to_string());
-        env.insert("GITLAB_HOST".to_string(), "env_host".to_string());
-        env.insert("GITLAB_TLS".to_string(), "yeS".to_string());
-        env.insert("GITLAB_FORMAT".to_string(), "Json".to_string());
+        env.insert("GITLABCLI_TOKEN".to_string(), "env_token".to_string());
+        env.insert("GITLABCLI_HOST".to_string(), "env_host".to_string());
+        env.insert("GITLABCLI_TLS".to_string(), "yeS".to_string());
+        env.insert("GITLABCLI_FORMAT".to_string(), "Json".to_string());
 
         update_config_from_env(&mut conf, env.into_iter());
 
@@ -677,7 +692,7 @@ mod config_unit_tests {
         assert_eq!(git_config.get_string("gitlab.host").unwrap(), "bradhost");
         assert_eq!(git_config.get_string("gitlab.projectid").unwrap(), "42");
         assert!(!git_config.get_bool("gitlab.tls").unwrap());
-        assert_eq!(git_config.get_string("gitlab.format").unwrap(), "JSON");
+        assert_eq!(git_config.get_string("gitlab.format").unwrap(), "json");
 
         reset_global_config();
         reset_xdg_config();
@@ -777,7 +792,7 @@ mod config_unit_tests {
         assert_eq!(single_level.get_entry("gitlab.host").unwrap().value().unwrap(), "testhost");
         assert_eq!(single_level.get_entry("gitlab.token").unwrap().value().unwrap(), "test-token");
         assert!(single_level.get_entry("gitlab.tls").is_err()); // it should error out looking this up
-        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "JSON");
+        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "json");
 
         // lets check Global to make sure it's not there
         single_level = get_level_config(&git_config, Global);
@@ -820,7 +835,7 @@ mod config_unit_tests {
         assert_eq!(single_level.get_entry("gitlab.host").unwrap().value().unwrap(), "testhost-globalxxx");
         assert_eq!(single_level.get_entry("gitlab.token").unwrap().value().unwrap(), "test-token-globalxxx");
         assert!(single_level.get_entry("gitlab.tls").is_err()); // it should error out looking this up
-        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "JSON");
+        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "json");
 
         // lets check Local to make sure it's not there
         single_level = get_level_config(&git_config, Local);
@@ -862,7 +877,7 @@ mod config_unit_tests {
         let mut single_level = get_level_config(&git_config, XDG);
         assert_eq!(single_level.get_entry("gitlab.host").unwrap().value().unwrap(), "testhost-xdg");
         assert_eq!(single_level.get_entry("gitlab.token").unwrap().value().unwrap(), "test-token-xdg");
-        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "JSON");
+        assert_eq!(single_level.get_entry("gitlab.format").unwrap().value().unwrap(), "json");
 
         // lets check Local to make sure it's not there
         single_level = get_level_config(&git_config, Local);
